Apply a score crosswalk to new values
Arguments
- equating
a
score_equatingfromequateScores().- values
numeric source-scale values to convert.
Value
numeric target-scale equivalents (linearly interpolated within the crosswalk, clamped to its range).
Apply a score crosswalk to new values
a score_equating from equateScores().
numeric source-scale values to convert.
numeric target-scale equivalents (linearly interpolated within the crosswalk, clamped to its range).