Score the modified Rankin Scale (mRS)
Arguments
- grade
A single global disability grade, 0-6.
- ...
Passed to
scoreInstrument().
Value
A ClinicalScore whose total is the grade and whose stratum is the disability label.
Score the modified Rankin Scale (mRS)
A single global disability grade, 0-6.
Passed to scoreInstrument().
A ClinicalScore whose total is the grade and whose stratum is the disability label.