Adds an instrument to the registry, either a ClinicalInstrument object, a parsed-spec list, or the path to a YAML spec file.
Arguments
- spec
A ClinicalInstrument, a spec list, or a path to a
.yamlfile.- overwrite
Replace an existing instrument with the same id? Default
FALSE(an existing id is an error).
Value
Invisibly, the registered ClinicalInstrument.
Examples
inst <- ClinicalInstrument(id = "toy2", items = c("a", "b"),
item_ranges = list(a = c(0, 1), b = c(0, 1)))
registerInstrument(inst)