Returns the packaged normal active range-of-motion reference values for the
major peripheral joints (shoulder, elbow, forearm, wrist, hip, knee, ankle).
These are the consensus clinical goniometry reference angles (in degrees) of
the American Academy of Orthopaedic Surgeons, as tabulated by Norkin & White,
Measurement of Joint Motion. They are single reference angles (not a
distribution), so use romNormalcy() for a reference / side-to-side
comparison; for a stratified z-score build a
GovernedNormativeReference() from a cohort dataset and use
normativeZScore().
References
American Academy of Orthopaedic Surgeons (1965). Joint Motion: Method of Measuring and Recording. Norkin CC, White DJ. Measurement of Joint Motion: A Guide to Goniometry. F.A. Davis.
Examples
romReference("knee")
#> joint motion plane reference_deg source
#> 1 knee flexion sagittal 135 AAOS/Norkin-White
#> 2 knee extension sagittal 0 AAOS/Norkin-White
romReference(motion = "flexion")
#> joint motion plane reference_deg source
#> 1 shoulder flexion sagittal 180 AAOS/Norkin-White
#> 2 elbow flexion sagittal 150 AAOS/Norkin-White
#> 3 wrist flexion sagittal 80 AAOS/Norkin-White
#> 4 hip flexion sagittal 120 AAOS/Norkin-White
#> 5 knee flexion sagittal 135 AAOS/Norkin-White